==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebLayoutChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebLayoutChangeEventArgsDescription } from "./WebLayoutChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebLayoutChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLayoutChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebLayoutChangeEventArgsDescriptionMetadata.a == null) {
                WebLayoutChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLayoutChangeEventArgsDescriptionMetadata.c(WebLayoutChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebLayoutChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebLayoutChangeEventArgsDescriptionMetadata.a);
            WebDockManagerLayoutDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:LayoutChangeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebDockManagerLayout");
        }
        static d(a) {
            WebLayoutChangeEventArgsDescriptionMetadata.b(a);
            a.ac("WebLayoutChangeEventArgs", () => new WebLayoutChangeEventArgsDescription());
            a.ab("WebLayoutChangeEventArgs", WebLayoutChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebLayoutChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebLayoutChangeEventArgsDescriptionMetadata, 'WebLayoutChangeEventArgsDescriptionMetadata');
    WebLayoutChangeEventArgsDescriptionMetadata.a = null;
    return WebLayoutChangeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebLayoutChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebLayoutChangeEventArgsDescription } from "./WebLayoutChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebLayoutChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLayoutChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebLayoutChangeEventArgsDescriptionMetadata.a == null) {
                WebLayoutChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLayoutChangeEventArgsDescriptionMetadata.c(WebLayoutChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebLayoutChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebLayoutChangeEventArgsDescriptionMetadata.a);
            WebDockManagerLayoutDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:LayoutChangeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebDockManagerLayout");
        }
        static d(a) {
            WebLayoutChangeEventArgsDescriptionMetadata.b(a);
            a.ae("WebLayoutChangeEventArgs", () => new WebLayoutChangeEventArgsDescription());
            a.ad("WebLayoutChangeEventArgs", WebLayoutChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebLayoutChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebLayoutChangeEventArgsDescriptionMetadata, 'WebLayoutChangeEventArgsDescriptionMetadata');
    WebLayoutChangeEventArgsDescriptionMetadata.a = null;
    return WebLayoutChangeEventArgsDescriptionMetadata;
})();
